==> haskell-tasty-smallcheck-0.8.1-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-smallcheck
version: 0.8.1
id: tasty-smallcheck-0.8.1-33p2Sp8mlYy703tkj5VYnp
key: tasty-smallcheck-0.8.1-33p2Sp8mlYy703tkj5VYnp
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: SmallCheck support for the Tasty test framework.
description:
    SmallCheck support for the Tasty test framework.
category: Testing
abi: f3b2c387d80b79acdadf1f4e43496c77
exposed: True
exposed-modules:
    Test.Tasty.SmallCheck
import-dirs: /usr/lib/ghc-8.6.3/site-local/tasty-smallcheck-0.8.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/tasty-smallcheck-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tasty-smallcheck-0.8.1
hs-libraries: HStasty-smallcheck-0.8.1-33p2Sp8mlYy703tkj5VYnp
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
    tasty-1.2-IwbKFXDCcs7DTBYkVTPhOw
haddock-interfaces: /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.1-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-smallcheck
version: 0.8.1
id: tasty-smallcheck-0.8.1-E5zfwQ8wYj24E8YM5xUrk
key: tasty-smallcheck-0.8.1-E5zfwQ8wYj24E8YM5xUrk
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: SmallCheck support for the Tasty test framework.
description:
    SmallCheck support for the Tasty test framework.
category: Testing
abi: 2815263f9f824fe1aecb21f9519b739b
exposed: True
exposed-modules:
    Test.Tasty.SmallCheck
import-dirs: /usr/lib/ghc-8.6.4/site-local/tasty-smallcheck-0.8.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/tasty-smallcheck-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/tasty-smallcheck-0.8.1
hs-libraries: HStasty-smallcheck-0.8.1-E5zfwQ8wYj24E8YM5xUrk
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2-BaVh72bbFlbBDnQetqR5pm
haddock-interfaces: /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
